@@ -1,5 +1,5 @@
 import os
-import itertools
+import string
 import sphc
 
 tf = sphc.TagFactory()
@@ -95,7 +95,9 @@ class HTML5Page(Page):
         html.body.container.main.main = self.main()
         html.body.container.footer = self.footer()
         html.body.bottombar = self.bottombar()
-        return (self.doctype + str(html)) % data
+        out = string.Template(str(html)).safe_substitute(data)
+        return (self.doctype + out)
+
 
     def write(self, outpath, data={}):
         """
@@ -131,7 +133,7 @@ class FieldContainer(object):
         self.fields.append(elem)
         return elem
 
-    def add_field(self, label='', input=None, fhelp=None, custom=False):
+    def add_field(self, label='', input=None, fhelp=None, container_classes=[]):
         """
         Adds common field to form.
         label: field label
@@ -145,6 +147,7 @@ class FieldContainer(object):
         """
         assert bool(input), 'input must be Tag object'
         field_box = tf.DIV(Class="field")
+        field_box.add_classes(container_classes)
         field_box.label_box = tf.DIV(Class='field-label')
         if label:
             # if input is not provided, generate input id for linking input with label
